@@ -6,7 +6,7 @@ glm.mi <- function (formula, mi.object, family = gaussian, ... )
     call   <- match.call( )
     m      <- m(mi.object)
     result <- vector( "list", m )
-    names( result ) <- as.character(paste( "Imputation", seq( m ), sep = "" ))
+    names( result ) <- as.character(paste( "Chain", seq( m ), sep = "" ))
     mi.data <- mi.completed(mi.object)
   
     for ( i in 1:m ) {
